.. _installation:
.. index:: Installation

Installation
============

:program:`PyTessel` is distributed via PyPI.

PyPI
------------

To install :program:`PyTessel` only for the current user, run::

    pip install pytessel